test/hotspot/gtest/memory/test_metaspace_allocation.cpp
changeset 51444 3e5d28e6de32
parent 49852 4d3218e5f170
child 54623 1126f0607c70
--- a/test/hotspot/gtest/memory/test_metaspace_allocation.cpp	Mon Aug 20 10:04:00 2018 +0200
+++ b/test/hotspot/gtest/memory/test_metaspace_allocation.cpp	Mon Aug 20 08:25:57 2018 -0400
@@ -102,9 +102,9 @@
       _spaces[i].lock = new Mutex(Monitor::native, "gtest-MetaspaceAllocationTest-lock", false, Monitor::_safepoint_check_never);
       ASSERT_TRUE(_spaces[i].lock != NULL);
     }
     // Let every ~10th space be an anonymous one to test different allocation patterns.
     const Metaspace::MetaspaceType msType = (os::random() % 100 < 10) ?
-      Metaspace::AnonymousMetaspaceType : Metaspace::StandardMetaspaceType;
+      Metaspace::UnsafeAnonymousMetaspaceType : Metaspace::StandardMetaspaceType;
     {
       // Pull lock during space creation, since this is what happens in the VM too
       // (see ClassLoaderData::metaspace_non_null(), which we mimick here).
@@ -102,9 +102,9 @@
       ASSERT_TRUE(_spaces[i].lock != NULL);
     }
-    // Let every ~10th space be an anonymous one to test different allocation patterns.
+    // Let every ~10th space be an unsafe anonymous one to test different allocation patterns.
     const Metaspace::MetaspaceType msType = (os::random() % 100 < 10) ?